Learn R Programming

longurl (version 0.1.1)

known_services: Retrieve all the URL shortener services known to the 'LongURL' API

Description

Retrieve all the URL shortener services known to the 'LongURL' API

Usage

known_services()

Arguments

Value

data_frame (compatible with data.frame) of results with the the short URL TLD in tld and a regular expression of compatible URLs in regex). Will populate the returned data.frame with NA if there are severe issues connecting to the LongURL API.

Examples

Run this code
short_svcs <- known_services()
head(short_svcs)

Run the code above in your browser using DataLab